@@ -11,15 +11,13 @@ alfa <- function(x, a, h = TRUE) {
   ## x contains the compositional data
   ## a is the power parameter, usually between -1 and 1
   ## if h is TRUE the multiplication with the Helmert matrix takes place
-
-  x <- as.matrix(x)  ## makes sure x is a matrix
+  x <-as.matrix(x)
   D <- dim(x)[2] ## number of components
   if ( D == 1 )   x <- t(x)
-  x <-x / Rfast::rowsums(x)  ## makes sure x is compositional data
 
   if ( a != 0 ) {
     z <- x^a
-    ta <- Rfast::rowsums(z) 
+    ta <- Rfast::rowsums(z)
     z <- z / ta
     z <- D / a * z - 1/a
     sa <- sum( log(ta) )
@@ -30,13 +28,11 @@ alfa <- function(x, a, h = TRUE) {
     sa <- dim(x)[1] * log(D)
   }
 
-  if ( h == TRUE ) {
+  if ( h ) {
     aff <- tcrossprod(z, helm( D ) ) ## multiply by the Helmert sub-matrix
     res <- list(sa = sa, aff = aff)
 
-  } else {
-    res <- list(sa = sa, aff = z)
-  }
+  } else  res <- list(sa = sa, aff = z)
 
   res
 
