@@ -7,24 +7,13 @@
 ddiri <- function(x, a, logged = TRUE) {
   ## x is the compositional data
   ## a is a vector with the parameters
-
   if ( is.null(dim(x)[1]) ) {
-    x <- x / sum(x)
     f <- lgamma( sum(a) ) - sum( lgamma(a) ) + sum( log(x) * (a - 1) )
+  } else  f <- lgamma( sum(a) ) - sum( lgamma(a) ) + as.vector( log(x) %*% (a - 1) )
 
-  } else {
-
-    x <- as.matrix(x)  ## makes sure x is a matrix
-    x <- x / Rfast::rowsums(x)  ## makes sure x is compositional data
-    f <- lgamma( sum(a) ) - sum( lgamma(a) ) + as.vector( log(x) %*% (a - 1) )
-  }
-
-  if ( logged == TRUE ) {
+  if ( logged ) {
     f <- f
-
-  } else {
-    f <- exp(f)
-  }
+  } else   f <- exp(f)
 
   f
 
