@@ -15,34 +15,27 @@ js.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
   ## if B==1 no bootstrap is performed and no standard errors are reported
   ## if ncores=1, then 1 processor is used, otherwise
   ## more are used (parallel computing)
-
-  y <- as.matrix(y)
-  y <- y / Rfast::rowsums(y)  ## makes sure y is compositional data
   n <- dim(y)[1]  ## sample size
-  mat <- model.matrix(y ~ ., as.data.frame(x) )
-  x <- mat[1:n, ]
+  x <- model.matrix(y ~ ., data.frame(x) )
   d <- dim(y)[2] - 1  ## dimensionality of the simplex
-  z <- list(y = y, x = x)
 
-  jsreg <- function(para, z = z){
-    y <- z$y   ;   x <- z$x
+  jsreg <- function(para, y, x, d){
     be <- matrix(para, byrow = TRUE, ncol = d)
     mu1 <- cbind( 1, exp(x %*% be) )
     mu <- mu1 / rowSums(mu1)
     M <- ( mu + y ) / 2
-    f <- sum( - y * log(1 + mu / y) + mu * log(mu / M), na.rm = TRUE )
-    f
+    sum( - y * log(1 + mu / y) + mu * log(mu / M), na.rm = TRUE )
   }
 
   ## the next lines minimize the kl.compreg function and obtain the estimated betas
-  ini <- as.vector( t( kl.compreg(y, x[, -1])$beta ) )
+  ini <- as.vector( t( kl.compreg(y, x[, -1])$be ) )
 
   runtime <- proc.time()
   options (warn = -1)
-  qa <- nlm(jsreg, ini, z = z)
-  qa <- nlm(jsreg, qa$estimate, z = z)
-  qa <- nlm(jsreg, qa$estimate, z = z)
-  beta <- matrix(qa$estimate, byrow = TRUE, ncol = d)
+  qa <- nlm(jsreg, ini, y = y, x = x, d = d)
+  qa <- nlm(jsreg, qa$estimate, y = y, x = x, d = d)
+  qa <- nlm(jsreg, qa$estimate, y = y, x = x, d = d)
+  be <- matrix(qa$estimate, byrow = TRUE, ncol = d)
   seb <- NULL
   runtime <- proc.time() - runtime
 
@@ -55,14 +48,13 @@ js.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
         ida <- sample( 1:n, n, replace = TRUE )
         yb <- y[ida, ]
         xb <- x[ida, ]
-        zb <- list(y = yb, x = xb)
-        ini <- as.vector( t( kl.compreg(yb, xb[, -1])$beta ) ) ## initial values
-        qa <- nlm(jsreg, ini, z = zb)
-        qa <- nlm(jsreg, qa$estimate, z = zb)
-        qa <- nlm(jsreg, qa$estimate, z = zb)
+        ini <- as.vector( t( kl.compreg(yb, xb[, -1])$be ) ) ## initial values
+        qa <- nlm(jsreg, ini, y = yb, x = xb, d = d)
+        qa <- nlm(jsreg, qa$estimate, y = yb, x = xb, d = d)
+        qa <- nlm(jsreg, qa$estimate, y = yb, x = xb, d = d)
         betaboot[i, ] <- qa$estimate
       }
-      s <- Rfast::colVars(ww, std = TRUE)
+      s <- Rfast::colVars(betaboot, std = TRUE)
       seb <- matrix(s, byrow = TRUE, ncol = d)
       runtime <- proc.time() - runtime
 
@@ -74,11 +66,10 @@ js.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
         ida <- sample(1:n, n, replace = TRUE)
         yb <- y[ida, ]
         xb <- x[ida, ]
-        zb <- list(y = yb, x = xb)
         ini <- as.vector( t( kl.compreg(yb, xb[, -1])$beta ) ) ## initial values
-        qa <- nlm(jsreg, ini, z = zb)
-        qa <- nlm(jsreg, qa$estimate, z = zb)
-        qa <- nlm(jsreg, qa$estimate, z = zb)
+        qa <- nlm(jsreg, ini, y = yb, x = xb, d = d)
+        qa <- nlm(jsreg, qa$estimate, y = yb, x = xb, d = d)
+        qa <- nlm(jsreg, qa$estimate, y = yb, x = xb, d = d)
         betaboot[i, ] <- qa$estimate
       }
       stopCluster(cl)
@@ -89,23 +80,16 @@ js.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
   }
 
   if ( is.null(xnew) ) {
-    mu <- cbind( 1, exp(x %*% beta) )
+    mu <- cbind( 1, exp(x %*% be) )
     est <- mu / Rfast::rowsums(mu)
   } else {
-    xnew <- model.matrix(y ~ ., as.data.frame(xnew) )
-    xnew <- xnew[1:dim(xnew)[1], ]
-    mu <- cbind(1, exp(xnew %*% beta))
+    xnew <- model.matrix(~., data.frame(xnew) )
+    mu <- cbind( 1, exp(xnew %*% be) )
     est <- mu / Rfast::rowsums(mu)
   }
 
-  if ( is.null(colnames(x)) ) {
-    p <- dim(x)[2] - 1
-    rownames(beta) <- c("constant", paste("X", 1:p, sep = "") )
-    if ( !is.null(seb) )  rownames(seb) <- c("constant", paste("X", 1:p, sep = "") )
-  } else {
-    rownames(beta)  <- c("constant", colnames(x)[-1] )
-    if  ( !is.null(seb) ) rownames(seb) <- c("constant", colnames(x)[-1] )
-  }
+  rownames(be)  <- colnames(x)
+  if  ( !is.null(seb) ) rownames(seb) <- colnames(x)
 
-  list(runtime = runtime, beta = beta, seb = seb, est = est)
+  list(runtime = runtime, be = be, seb = seb, est = est)
 }
