@@ -13,19 +13,19 @@
 ################################
 
 mkde <- function(x, h, thumb = "none") {
-  x <- as.matrix(x)  ## makes sure x is a matrix
   ## h is the h you want, which is either a vector or a single number
   ## thumb can be either "none" so the specified h is used, or
   ## "scott", or "silverman"
+
   n <- dim(x)[1]
   d <- dim(x)[2]  ## sample and dimensionality of x
 
   if ( thumb == "silverman" ) {
-    s <- Rfast::colVars(x, std = TRUE) 
+    s <- Rfast::colVars(x, std = TRUE)
     h <- ( 4/(d + 2) )^( 1/(d + 4) ) * s * n^( -1/(d + 4) )
 
   } else  if ( thumb == "scott" ) {
-    s <- Rfast::colVars(x, std = TRUE) 
+    s <- Rfast::colVars(x, std = TRUE)
     h <- s * n^( -1/(d + 4) )
 
   } else if ( thumb == "estim" ) {
@@ -40,7 +40,6 @@ mkde <- function(x, h, thumb = "none") {
   con <- prod( diag( h ) )
   y <- x %*% h
   a1 <- fields::rdist(y, compact = FALSE)
-  f <- (0.5 / pi)^(d/2) * con * Rfast::rowmeans( exp(-0.5 * a1^2 ) )
-  f
+  (0.5 / pi)^(d/2) * con * Rfast::rowmeans( exp(-0.5 * a1^2 ) )
 
 }
