@@ -12,25 +12,23 @@ multivreg <- function(y, x, plot = TRUE, xnew = NULL) {
   ## x contains the independent variable(s) which have to be
   ## in a matrix format or a vector if you have just one
 
-  y <- as.matrix(y)
-  x <- as.matrix(x)
   n <- dim(y)[1]  ## sample size
   d <- dim(y)[2]  ## dimensionality of y
+  x <- as.matrix(x)
   p <- dim(x)[2]  ## dimensionality of x
   mod <- lm(y ~ x)   ## linear regression
   res <- resid(mod)  ## residuals
   s <- cov(res) * (n - 1) / (n - p - 1)
   sxx <- cov(x)  ## covariance of the independent variables
-  dres <- sqrt( Rfast::rowsums( res %*% solve(s) * res ) ) ## Mahalanobis distances
+  dres <- sqrt( Rfast::mahala( res, numeric(d), s ) ) ## Mahalanobis distances
   ## of the residuals
-
   mx <- Rfast::colmeans(x)  ## mean vector of the independent variales
   dx <- sqrt( Rfast::mahala(x, mx, sxx) )  ## Mahalanobis distances
   ## of the independent variables
   crit.res <- sqrt( qchisq(0.975, d) )
   crit.x <- sqrt( qchisq(0.975, p) )
 
-  if (plot == TRUE) {
+  if ( plot ) {
     plot(dx, dres, xlim = c(0, max(dx) + 0.5), ylim = c(0, max(dres) + 0.5),
          xlab = "Mahalanobis distance of x", ylab = "Mahalanobis distance
          of residuals")
@@ -56,16 +54,14 @@ multivreg <- function(y, x, plot = TRUE, xnew = NULL) {
 
   for (i in 1:d) {
     wa <- as.matrix( coef(moda[[i]]) )
-    wa <- cbind( wa, wa[, 1] - qt(0.975, n - p - 1) * mse[i] ,
-                 wa[, 1] + qt(0.975, n - p - 1) * mse[i] )
+    wa <- cbind( wa, wa[, 1] - qt(0.975, n - p - 1) * mse[i], wa[, 1] + qt(0.975, n - p - 1) * mse[i] )
     colnames(wa)[5:6] <- paste(c(2.5, 97.5), "%", sep = "")
     suma[, , i] <- wa
     r.squared[i] <- as.numeric( moda[[i]]$r.squared )
   }
 
   if ( is.null(colnames(y)) ) {
-    dimnames(suma) <- list( rownames(wa), colnames(wa),
-                            paste("Y", 1:d, sep = "") )
+    dimnames(suma) <- list( rownames(wa), colnames(wa), paste("Y", 1:d, sep = "") )
     names(r.squared) <- paste("Y", 1:d, sep = "")
     colnames(est) <- paste("Y", 1:d, sep = "")
   } else {
