@@ -17,30 +17,23 @@ ols.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
   ## more are used (parallel computing)
 
   runtime <- proc.time()
-  y <- as.matrix(y)
-  y <- y / Rfast::rowsums(y) ## makes sure y is compositional data
-  mat <- model.matrix(y ~ ., as.data.frame(x) )
+  x <- model.matrix(y ~ ., data.frame(x) )
   n <- dim(y)[1]  ## sample size
-  x <- mat[1:n, ]
   d <- dim(y)[2] - 1  ## dimensionality of the simplex
   z <- list(y = y, x = x)
 
-  olsreg <- function(para, z) {
-    y <- z$y
-    x <- z$x
-    d <- dim(y)[2] - 1
+  olsreg <- function(para, y, x, d) {
     be <- matrix(para, byrow = TRUE, ncol = d)
     mu1 <- cbind(1, exp(x %*% be))
     mu <- mu1 / rowSums(mu1)
     sum( (y - mu)^2 )
   }
-
   ## the next lines minimize the reg function and obtain the estimated betas
   ini <- as.vector( t( coef(lm.fit(x, y[, -1]) ) ) )  ## initial values
   options (warn = -1)
-  qa <- nlm(olsreg, ini, z = z)
-  qa <- nlm(olsreg, qa$estimate, z = z)
-  qa <- nlm(olsreg, qa$estimate, z = z)
+  qa <- nlm(olsreg, ini, y = y, x = x, d = d)
+  qa <- nlm(olsreg, qa$estimate, y = y, x = x, d = d)
+  qa <- nlm(olsreg, qa$estimate, y = y, x = x, d = d)
   beta <- matrix(qa$estimate, byrow = TRUE, ncol = d)
   seb <- NULL
   runtime <- proc.time() - runtime
@@ -54,14 +47,13 @@ ols.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
         ida <- sample(1:n, n, replace = TRUE)
         yb <- y[ida, ]
         xb <- x[ida, ]
-        zb <- list(y = yb, x = xb)
         ini <- as.vector( t( coef(lm.fit(xb, yb[, -1]) ) ) )  ## initial values
-        qa <- nlm(olsreg, ini, z = zb)
-        qa <- nlm(olsreg, qa$estimate, z = zb)
-        qa <- nlm(olsreg, qa$estimate, z = zb)
+        qa <- nlm(olsreg, ini, y = yb, x = xb, d = d)
+        qa <- nlm(olsreg, qa$estimate, y = yb, x = xb, d = d)
+        qa <- nlm(olsreg, qa$estimate, y = yb, x = xb, d = d)
         betaboot[i, ] <- qa$estimate
       }
-      s <- Rfast::colVars(ww, std = TRUE)
+      s <- Rfast::colVars(betaboot, std = TRUE)
       seb <- matrix(s, byrow = TRUE, ncol = d)
       runtime <- proc.time() - runtime
 
@@ -74,11 +66,10 @@ ols.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
         ida <- sample(1:n, n, replace = TRUE)
         yb <- y[ida, ]
         xb <- x[ida, ]
-        zb <- list(y = yb, x = xb)
         ini <- as.vector( t( coef(lm.fit(xb, yb[, -1]) ) ) )  ## initial values
-        qa <- nlm(olsreg, ini, z = zb)
-        qa <- nlm(olsreg, qa$estimate, z = zb)
-        qa <- nlm(olsreg, qa$estimate, z = zb)
+        qa <- nlm(olsreg, ini, y = yb, x = xb, d = d)
+        qa <- nlm(olsreg, qa$estimate, y = yb, x = xb, d = d)
+        qa <- nlm(olsreg, qa$estimate, y = yb, x = xb, d = d)
         betaboot[i, ] <- qa$estimate
       }
       stopCluster(cl)
@@ -92,20 +83,13 @@ ols.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
     mu <- cbind( 1, exp(x %*% beta) )
     est <- mu / Rfast::rowsums(mu)
   } else {
-    xnew <- model.matrix(y ~ ., as.data.frame(xnew) )
-    xnew <- xnew[1:dim(xnew)[1], ]
+    xnew <- model.matrix(~., data.frame(xnew) )
     mu <- cbind(1, exp(xnew %*% beta))
     est <- mu / Rfast::rowsums(mu)
   }
 
-  if ( is.null(colnames(x)) ) {
-    p <- dim(x)[2] - 1
-    rownames(beta) <- c("constant", paste("X", 1:p, sep = "") )
-    if ( !is.null(seb) )  rownames(seb) <- c("constant", paste("X", 1:p, sep = "") )
-  } else {
-    rownames(beta)  <- c("constant", colnames(x)[-1] )
-    if  ( !is.null(seb) ) rownames(seb) <- c("constant", colnames(x)[-1] )
-  }
+  rownames(beta)  <- colnames(x)
+  if  ( !is.null(seb) ) rownames(seb) <- colnames(x)
 
   list(runtime = runtime, beta = beta, seb = seb, est = est)
 }
