@@ -8,15 +8,11 @@
 ################################
 
 pcr.tune <- function(y, x, M = 10, maxk = 50, mat = NULL, ncores = 1, graph = TRUE) {
-
   ## y is the univariate dependent variable
   ## x contains the independent variables(s)
   ## M is the number of folds, set to 10 by default
   ## maxk is the maximum number of eigenvectors to conside
   ## ncores specifies how many cores to use
-
-  y <- as.vector(y)  ## makes sure y is a vector
-  x <- as.matrix(x)
   n <- length(y)  ## sample size
   p <- dim(x)[2]  ## number of independent variables
   if ( maxk > p )  maxk <- p  ## just a check
@@ -30,16 +26,14 @@ pcr.tune <- function(y, x, M = 10, maxk = 50, mat = NULL, ncores = 1, graph = TR
     mat <- matrix( nu, ncol = M )
   } else  mat <- mat
 
-  M <- ncol(mat)
-  rmat <- nrow(mat)
+  M <- dim(mat)[2]
+  rmat <- dim(mat)[1]
   ntrain <- n - rmat
   msp <- matrix( nrow = M, ncol = maxk )
-
   ## deigma will contain the positions of the test set
   ## this is stored but not showed in the end
   ## the user can access it though by running
   ## the commands outside this function
-
   if (ncores == 1) {
 
     runtime <- proc.time()
@@ -55,17 +49,14 @@ pcr.tune <- function(y, x, M = 10, maxk = 50, mat = NULL, ncores = 1, graph = TR
       ytrain <- ytrain - m  ## standardize the dependent variable
       mx <- Rfast::colmeans(xtrain)
       s <- Rfast::colVars(xtrain, std = TRUE)
-
       mtrain <- t( xtrain )
       mtrain <- mtrain - mx
       mtrain <- mtrain / sqrt( Rfast::rowsums(mtrain^2) )
       sar <- tcrossprod( mtrain )
-
       eig <- eigen( sar )  ## eigen analysis of the design matrix
       vec <- eig$vectors  ## eigenvectors, or principal components
       z <- xtrain %*% vec  ## PCA scores
-      xnew <- ( t(xtest) - mx ) / s  ## standardize the xnew values
-      xnew <- t(xnew)
+      xnew <- t( ( t(xtest) - mx ) / s ) ## standardize the xnew values
 
       for ( j in 1:maxk ) {
         zzk <- crossprod(z[, 1:j])
@@ -74,7 +65,6 @@ pcr.tune <- function(y, x, M = 10, maxk = 50, mat = NULL, ncores = 1, graph = TR
         est <- as.vector( m + xnew %*% be )  ## predicted values for PCA model
         msp[vim, j] <- sum( (ytest - est)^2 ) / rmat
       }
-
     }
 
     runtime <- proc.time() - runtime
@@ -99,12 +89,10 @@ pcr.tune <- function(y, x, M = 10, maxk = 50, mat = NULL, ncores = 1, graph = TR
       ytrain <- ytrain - m  ## standardize the dependent variable
       mx <- Rfast::colmeans(xtrain)
       s <- Rfast::colVars(xtrain, std = TRUE)
-
       mtrain <- t( xtrain )
       mtrain <- mtrain - mx
       mtrain <- mtrain / sqrt( Rfast::rowsums(mtrain^2) )
       sar <- tcrossprod( mtrain )
-
       eig <- eigen( sar )  ## eigen analysis of the design matrix
       vec <- eig$vectors  ## eigenvectors, or principal components
       z <- xtrain %*% vec  ## PCA scores
@@ -113,24 +101,22 @@ pcr.tune <- function(y, x, M = 10, maxk = 50, mat = NULL, ncores = 1, graph = TR
         zzk <- crossprod(z[, 1:j])
         be <- vec[, 1:j] %*% solve( zzk, crossprod( z[, 1:j], ytrain ) )
         ## b is the PCA based coefficients
-        xnew <- ( t(xtest) - mx ) / s  ## standardize the xnew values
-        xnew <- t(xnew)
+        xnew <- t( ( t(xtest) - mx ) / s ) ## standardize the xnew values
         est <- as.vector( m + xnew %*% be )  ## predicted values for PCA model
         er[j] <- sum( (ytest - est)^2 ) / rmat
       }
       return(er)
     }
-
     stopCluster(cl)
 
     runtime <- proc.time() - runtime
   }
 
-  mspe <- Rfast::colmeans(msp) 
-  bias <- msp[ ,which.min(mspe)] - apply(msp, 1, min)  ## TT estimate of bias
+  mspe <- Rfast::colmeans(msp)
+  bias <- msp[ ,which.min(mspe)] - Rfast::rowMins(msp, value = TRUE)   ## apply(msp, 1, min)  ## TT estimate of bias
   estb <- mean( bias )  ## TT estimate of bias
 
-  if ( graph == TRUE ) {
+  if ( graph ) {
     plot(1:maxk, mspe, xlab = "Number of principal components",
     ylab = "MSPE", type = "b")
   }
