@@ -10,11 +10,9 @@ rcompnorm <- function(n, m, s, type = "alr") {
   ## m is the mean vector in R^d
   ## s is the covariance matrix in R^d
   ## type is either alr or ilr
-
-  x <- rmvnorm(n, m, s)
+  x <- Rfast::rmvnorm(n, m, s)
   if ( type == "alr" ) {
     y <- cbind( 1, exp(x) )
-
   } else {
     D <- dim(x)[2]
     y <- x %*% helm(D + 1)
