@@ -13,6 +13,7 @@ rmixcomp <- function(n, prob, mu, sigma, type = "alr") {
   ## p is a vector with the mixing probabilities
   ## mu is a matrix with with the mean vectors
   ## sigma is an array with the covariance matrices
+
   p2 <- c(0, cumsum(prob))
   p <- ncol(mu)  ## dimensionality of the data
   u <- runif(n)
@@ -22,28 +23,19 @@ rmixcomp <- function(n, prob, mu, sigma, type = "alr") {
   nu <- as.vector( table(ina) )  ## frequency table of each cluster
   y <- array( dim = c(n, p, g) )
 
-  for (j in 1:g) {
-    y[1:nu[j], , j] <- rmvnorm( nu[j], mu[j, ], sigma[ , , j])
-  }
-
+  for (j in 1:g)  y[1:nu[j], , j] <- Rfast::rmvnorm( nu[j], mu[j, ], sigma[ , , j])
   x <- y[1:nu[1], , 1]
-
-  for (j in 2:g) {
-    x <- rbind(x, y[1:nu[j], , j])
-  }
+  for (j in 2:g)  x <- rbind(x, y[1:nu[j], , j])
 
   if (type == "alr") {
     x1 <- cbind(1, exp(x) )
-    x <- x1 / Rfast::rowsums(x1) 
-
+    x <- x1 / Rfast::rowsums(x1)
   } else {
     x1 <- tcrossprod( x, helm( p + 1) )
     x2 <- exp(x1)
-    x <- x2 / Rfast::rowsums( x2 ) 
+    x <- x2 / Rfast::rowsums( x2 )
   }
-
   ## x is the simulated data
   ## data come from the first cluster, then from the second and so on
-
   list(id = ina, x = x)
 }
